<?php

/**
 * @file
 * Post update functions for CKEditor 5 IMCE private.
 */

use Drupal\Core\Config\Entity\ConfigEntityUpdater;
use Drupal\editor\Entity\Editor;

/**
 * The image_private toolbar items changed.
 *
 * `imce_public_image` and `imce_public_link` changed
 * to `imce_private_public_image` and `imce_private_public_link`.
 */
function imce_private_post_update_imce_private_toolbar_item(&$sandbox = []) {
  $config_entity_updater = \Drupal::classResolver(ConfigEntityUpdater::class);

  $callback = function (Editor $editor) {
    // Only try to update editors using CKEditor 5.
    if ($editor->getEditor() !== 'ckeditor5') {
      return FALSE;
    }

    $needs_update = FALSE;
    $settings = $editor->getSettings();

    // Only update if the editor is using the `imce_public_image` toolbar item.
    if (is_array($settings['toolbar']['items']) && in_array('imce_public_image', $settings['toolbar']['items'], TRUE)) {
      // Replace `imce_public_image` with `imce_private_public_image`.
      $settings['toolbar']['items'] = str_replace('imce_public_image', 'imce_private_public_image', $settings['toolbar']['items']);
      $needs_update = TRUE;
    }
    // Only update if the editor is using the `imce_public_link` toolbar item.
    if (is_array($settings['toolbar']['items']) && in_array('imce_public_link', $settings['toolbar']['items'], TRUE)) {
      // Replace `imce_public_link` with `imce_private_public_link`.
      $settings['toolbar']['items'] = str_replace('imce_public_link', 'imce_private_public_link', $settings['toolbar']['items']);
      $needs_update = TRUE;
    }
    if ($needs_update) {
      $editor->setSettings($settings);
    }
    return $needs_update;
  };

  $config_entity_updater->update($sandbox, 'editor', $callback);
}
