<?php

// phpcs:disable Drupal.NamingConventions.ValidFunctionName.ScopeNotCamelCaps
declare(strict_types=1);

namespace Drupal\imce_private\Plugin\CKEditor4To5Upgrade;

use Drupal\ckeditor5\HTMLRestrictions;
use Drupal\ckeditor5\Plugin\CKEditor4To5UpgradePluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\filter\FilterFormatInterface;

/**
 * CKEditor 4 to 5 upgrade for IMCE_private module's CKEditor 4 plugins.
 *
 * @CKEditor4To5Upgrade(
 *   id = "imce_private",
 *   cke4_buttons = {
 *     "ImceImagePrivate",
 *     "ImceLinkPrivate",
 *     "ImceImagePublic",
 *     "ImceLinkPublic",
 *   },
 *   cke4_plugin_settings = {
 *   },
 *   cke5_plugin_elements_subset_configuration = {
 *   }
 * )
 *
 * @internal
 *   Plugin classes are internal.
 */
class ImcePrivate extends PluginBase implements CKEditor4To5UpgradePluginInterface {

  /**
   * {@inheritdoc}
   */
  public function mapCKEditor4ToolbarButtonToCKEditor5ToolbarItem(string $cke4_button, HTMLRestrictions $text_format_html_restrictions): ?array {
    switch ($cke4_button) {
      case 'ImceImagePrivate':
        return ['imce_private_image'];

      case 'ImceLinkPrivate':
        return ['imce_private_link'];

      case 'ImceImagePublic':
        return ['imce_private_public_image'];

      case 'ImceLinkPublic':
        return ['imce_private_public_link'];

      default:
        throw new \OutOfBoundsException();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function mapCKEditor4SettingsToCKEditor5Configuration(string $cke4_plugin_id, array $cke4_plugin_settings): ?array {
    throw new \OutOfBoundsException();
  }

  /**
   * {@inheritdoc}
   */
  public function computeCKEditor5PluginSubsetConfiguration(string $cke5_plugin_id, FilterFormatInterface $text_format): ?array {
    throw new \OutOfBoundsException();
  }

}
